@@ -10,5 +10,5 @@ class DetectTask:
     def perform(clz, detection_type, image_path, key):
         image_data = config.loader.load_sync(image_path)
         points = clz.processor.detect(detection_type, image_data)
-        result_store = ResultStore()
+        result_store = ResultStore(clz.resq.redis)
         result_store.store(key, points)
